==> haskell-doctemplates-0.2.1-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.2.1
id: doctemplates-0.2.1-HpGPuFCXHVo8bXWLtrjs4f
key: doctemplates-0.2.1-HpGPuFCXHVo8bXWLtrjs4f
license: BSD3
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    A simple text templating system used by pandoc.
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    Text.DocTemplates
abi: 8b5018dfbf90ba951c63def0b34e248c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/doctemplates-0.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/doctemplates-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-doctemplates
hs-libraries: HSdoctemplates-0.2.1-HpGPuFCXHVo8bXWLtrjs4f
depends:
    base-4.10.1.0 aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU
    bytestring-0.10.8.2 blaze-markup-0.8.2.0-CnWoybGhIGoVpPCZ0nkq3
    blaze-html-0.9.0.1-HT9MGj6kW7JIH7aaLXkr1R
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj containers-0.5.10.2
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F
    unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz
    scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU=34f15a624c6fc087743b1cf3621b819b
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             blaze-markup-0.8.2.0-CnWoybGhIGoVpPCZ0nkq3=88ae80c9035b7e1542563395a63147b4
             blaze-html-0.9.0.1-HT9MGj6kW7JIH7aaLXkr1R=73d2b9544f01cd8acaf404bd9dc45c3e
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
             parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F=688f5e7444a80128e4a1c39bd128d195
             unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz=9d795026e0df763f1ffeaf92b7adcdda
             scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG=490d099f5e386f4f486a599d7d1e6789
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.2.2.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.2.2.1
id: doctemplates-0.2.2.1-8DQPfvJJXjjBoivd1Mbpub
key: doctemplates-0.2.2.1-8DQPfvJJXjjBoivd1Mbpub
license: BSD3
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    A simple text templating system used by pandoc.
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    Text.DocTemplates
abi: 9e389102690cfdc900d6dcc3501861d1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/doctemplates-0.2.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/doctemplates-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-doctemplates
hs-libraries: HSdoctemplates-0.2.2.1-8DQPfvJJXjjBoivd1Mbpub
depends:
    base-4.10.1.0 aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU
    bytestring-0.10.8.2 blaze-markup-0.8.2.1-Cc3m1hen7WY3VxZJEwMXDb
    blaze-html-0.9.0.1-HqpSz28u1FiCfAogiiZCfO
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj containers-0.5.10.2
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F
    unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz
    scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU=34f15a624c6fc087743b1cf3621b819b
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             blaze-markup-0.8.2.1-Cc3m1hen7WY3VxZJEwMXDb=e08bcee0ef3e79aea016c4a61a6fce39
             blaze-html-0.9.0.1-HqpSz28u1FiCfAogiiZCfO=5b9e50f475d80821e5ba250ac60c1064
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
             parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F=688f5e7444a80128e4a1c39bd128d195
             unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz=9d795026e0df763f1ffeaf92b7adcdda
             scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG=490d099f5e386f4f486a599d7d1e6789
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
